@@ -19,7 +19,7 @@ import numpy as np
 from contextlib import contextmanager
 from pathlib import Path
 
-from .basedatadir import BaseDataDir, create_basedatadir
+from .datadir import DataDir, create_datadir
 from .metadata import MetaData
 from .numtype import arrayinfotodtype, arraynumtypeinfo, numtypesdescr
 from .readcodearray import readcode
@@ -39,8 +39,8 @@ __all__ = ['Array', 'asarray', 'create_array', 'delete_array',
 class AppendDataError(Exception):
     pass
 
-
-class Array(BaseDataDir):
+#FIXME do not subclass from BaseDataDir, instead make this an attribute
+class Array:
     """Instantiate a Darr array from disk.
 
     A darr array corresponds to a directory containing 1) a binary file with
@@ -64,13 +64,15 @@ class Array(BaseDataDir):
     _arraydescrfilename = 'arraydescription.json'
     _metadatafilename = 'metadata.json'
     _readmefilename = 'README.txt'
-    _filenames = {_arraydescrfilename, _datafilename,
-                  _readmefilename,
-                  _metadatafilename} | BaseDataDir._filenames
+    _protectedfiles = {_arraydescrfilename, _datafilename,
+                       _readmefilename,
+                       _metadatafilename}
     _formatversion = get_versions()['version']
 
     def __init__(self, path, accessmode='r'):
-        BaseDataDir.__init__(self, path=path)
+        self._datadir = DataDir(path=path,
+                                protectedpaths=self._protectedfiles)
+        self._path = self._datadir._path
         self._datapath = self._path / self._datafilename
         self._accessmode = check_accessmode(accessmode)
         self._arraydescrpath = self._path / self._arraydescrfilename
@@ -83,7 +85,8 @@ class Array(BaseDataDir):
             self._shape = ar.shape
             self._size = ar.size
         self._metadata = MetaData(self._path / self._metadatafilename,
-                                  accessmode=accessmode)
+                                  accessmode=accessmode,
+                                  callatfilecreationordeletion=self._update_readmetxt)
 
     @property
     def _arrayinfo(self):
@@ -101,6 +104,13 @@ class Array(BaseDataDir):
                                             makebinary=False)
         self._metadata.accessmode = value
 
+    @property
+    def datadir(self):
+        """Data directory object with many useful methods, such as
+        writing information to text or json files, archiving all data,
+        calculating checksums etc."""
+        return self._datadir
+
     @property
     def dtype(self):
         """Numpy data type of the array values."""
@@ -131,6 +141,11 @@ class Array(BaseDataDir):
         """Number of dimensions """
         return len(self._shape)
 
+    @property
+    def path(self):
+        """File system path to array data"""
+        return self._path
+
     @property
     def shape(self):
         """Tuple with sizes of each axis of the data array."""
@@ -259,8 +274,8 @@ class Array(BaseDataDir):
         """
         requiredkeys = {'numtype', 'shape', 'arrayorder', 'darrversion'}
         try:
-            d = self._read_jsondict(filename=self._arraydescrfilename,
-                                    requiredkeys=requiredkeys)
+            d = self._datadir.read_jsondict(filename=self._arraydescrfilename,
+                                            requiredkeys=requiredkeys)
         except Exception as e:
             m = f". Could not read array description from "\
                 f"'{self._arraydescrpath}. '"
@@ -308,8 +323,8 @@ class Array(BaseDataDir):
     def _update_arrayinfo(self, *args, **kwargs):
         arrayinfo = self._arrayinfo
         arrayinfo.update( *args, **kwargs)
-        self._write_jsondict(filename=self._arraydescrfilename,
-                             d=arrayinfo, overwrite=True)
+        self._datadir._write_jsondict(filename=self._arraydescrfilename,
+                                      d=arrayinfo, overwrite=True)
 
     def _update_len(self, lenincrease):
         newshape = list(self.shape)
@@ -321,7 +336,7 @@ class Array(BaseDataDir):
 
     def _update_readmetxt(self):
         txt = readcodetxt(self)
-        self._write_txt(self._readmefilename, txt, overwrite=True)
+        self._datadir._write_txt(self._readmefilename, txt, overwrite=True)
 
     def append(self, array):
         """ Add array-like objects to darr to the end of the dataset.
@@ -712,6 +727,7 @@ def _archunkgenerator(array, dtype=None, chunklen=None):
             f"cannot convert object of type '{type(array)}' to an array")
 
 
+# FIXME what it iter produces a different first dimension?
 def asarray(path, array, dtype=None, accessmode='r',
             metadata=None, chunklen=None, overwrite=False):
     """Save an array or array generator as a Darr array to file system path.
@@ -794,7 +810,7 @@ def asarray(path, array, dtype=None, accessmode='r',
         raise TypeError(f"darr cannot have type "
                         f"'{firstchunk.dtype.name}'")
     dtype = firstchunk.dtype
-    bd = create_basedatadir(path=path, overwrite=overwrite)
+    bd = create_datadir(path=path, overwrite=overwrite)
     datapath = path.joinpath(Array._datafilename)
     arraylen = firstchunk.shape[0]
     with open(datapath, 'wb') as df:
@@ -934,7 +950,7 @@ def delete_array(da):
     except Exception:
         raise TypeError(f"'{da}' not recognized as a Darr array")
     da.check_arraywriteable()
-    for fn in da._filenames:
+    for fn in da._protectedfiles:
         path = da.path.joinpath(fn)
         if path.exists():
             path.unlink()
@@ -1017,9 +1033,10 @@ def readcodetxt(da):
     """
 
     s = numtypedescriptiontxt(da)
-    s += "Example code for reading the numeric data without Darr\n" \
-         "=======================================================\n\n"
+    s += "Example code for reading the numeric data\n" \
+         "=========================================\n\n"
     languages = (
+        ("Python with Darr:", "darr"),
         ("Python with Numpy:", "numpy"),
         ("Python with Numpy (memmap):", "numpymemmap"),
         ("R:", "R"),
@@ -1064,21 +1081,14 @@ def numtypedescriptiontxt(da):
                           'with memory address'
     else:
         raise ValueError(f'arrayorder type "{arrayorder}" unknown')
-    s = wrap("This directory contains a numeric array that can be accessed "
-             "in Python using the Darr library "
-             "(https://pypi.org/project/darr/), but that can also be "
-             "accessed  easily in other environments. In Darr, do:") + "\n\n"
-    s +=     ">>> import darr\n" \
-             ">>> a = darr.Array('path_to_array_dir')\n\n"
-    s += wrap("where 'path_to_array_dir' is the name of the array "
-              "directory, which is the one that also contains this README.")\
-         + "\n\n"
-    s += wrap("If the Darr library is not available, it should be "
-              "straightforward to access the data based on the information "
-              "below. This includes code for a number of popular "
-              "platforms, in which case it is a matter of copying a few "
-              "lines.")  + "\n\n\n"
-    s+= f"Description of data format\n==========================\n\n"
+    s = wrap("This directory contains a numeric array that is stored in an "
+             "open and simple format and that is easy to access in most "\
+             "analysis environments. In Python, you can use the Darr "\
+             "library (https://pypi.org/project/darr/), which was used to "\
+             "create the data. If Darr is not available, it is "\
+             "straightforward to access the data using the information "\
+             "below, which includes code for a number of popular platforms.")  + "\n\n\n"
+    s+= f"Data format\n===========\n\n"
     s += wrap("The file 'arrayvalues.bin' contains a numeric array in the "
               "following format:") + "\n\n"
     s +=f"  Numeric type: {typedescr}\n" \
@@ -1093,6 +1103,7 @@ def numtypedescriptiontxt(da):
     s += wrap("Format details are also stored in json format in the separate "
               "UTF-8 text file, 'arraydescription.json' to facilitate "
               "automatic reading by a program.") + "\n\n"
-    s += wrap("If present, the file 'metadata.json' contains metadata in json "
-              "UTF-8 text format.") + "\n\n\n"
+    if len(da.metadata) > 0:
+        s += wrap("The file 'metadata.json' contains metadata in json UTF-8 "\
+                  "text format.") + "\n\n\n"
     return s
